|pypi| |actions| |codecov| |downloads|


edc-dashboard
-------------

Core classes for dashboards used by the EDC. e.g. Listboard, SubjectDashboard


.. |pypi| image:: https://img.shields.io/pypi/v/edc-dashboard.svg
    :target: https://pypi.python.org/pypi/edc-dashboard

.. |actions| image:: https://github.com/clinicedc/edc-dashboard/actions/workflows/build.yml/badge.svg
  :target: https://github.com/clinicedc/edc-dashboard/actions/workflows/build.yml

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-dashboard/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/clinicedc/edc-dashboard

.. |downloads| image:: https://pepy.tech/badge/edc-dashboard
   :target: https://pepy.tech/project/edc-dashboard
